from setuptools import setup, find_packages

setup(name='eds_ds_tools',
      version='1.0',
      description='tools for data science',
      #packages=['eds_ds_tools'],
      author_email='wenleicao@gmail.com',
      zip_safe=False,      
      packages=find_packages(where="."),
        package_dir={"": "."},
        package_data={
            'eds_ds_tools': ['*.zip'], # Include all .zip files in 'eds_ds_tools'
        },
        include_package_data=True
      
      )
